@@ -1,10 +1,9 @@
 #!/usr/bin/env bash
-TRSCRIPT=$(printf $1 | tr - _)
 cat > $1/src/Makefile.am <<EOF
 bin_SCRIPTS = $1
 EXTRA_DIST = main.sh
 CLEANFILES = \$(bin_SCRIPTS)
-${TRSCRIPT}: main.sh Makefile
+${1}: main.sh Makefile
 	cp \$(srcdir)/main.sh $1
 	chmod +x $1
 EOF
