@@ -1,6 +1,5 @@
 #!/usr/bin/env bash
-TRPROGRAM=$(printf $1 | tr - _)
 cat > $1/src/Makefile.am <<EOF
 bin_PROGRAMS = $1
-${TRPROGRAM}_SOURCES = main.cpp
+${1}_SOURCES = main.cpp
 EOF
